@@ -603,7 +603,9 @@ vwl_log_handler(const char *fmt, va_list args)
     // Remove newline that libwayland puts
     buf[STRLEN(buf) - 1] = NUL;
 
+#ifdef FEAT_EVAL
     ch_log(NULL, "%s", buf);
+#endif
     emsg(buf);
 
     vim_free(buf);
@@ -907,21 +909,14 @@ vwl_destroy_seat(vwl_seat_T *seat)
 
 /*
  * Return a seat with the give name/label. If none exists then NULL is returned.
- * If NULL or an empty string is passed as the label then $XDG_SEAT is used
- * else the first available seat found is used.
+ * If NULL or an empty string is passed as the label then the first available
+ * seat found is used.
  */
     static vwl_seat_T *
 vwl_get_seat(const char *label)
 {
     if ((STRCMP(label, "") == 0 || label == NULL) && vwl_seats.ga_len > 0)
-    {
-	const char *xdg_seat = (char*)mch_getenv("XDG_SEAT");
-
-	if (xdg_seat == NULL)
 	    return &((vwl_seat_T *)vwl_seats.ga_data)[0];
-	else
-	    label = xdg_seat;
-    }
 
     for (int i = 0; i < vwl_seats.ga_len; i++)
     {
@@ -2105,7 +2100,7 @@ vwl_data_device_listener_finished(vwl_data_device_T *device)
 {
     vwl_clipboard_selection_T *clip_sel = device->data;
 
-    vwl_data_device_destroy(device, FALSE);
+    vwl_data_device_destroy(&clip_sel->device, FALSE);
     vwl_data_offer_destroy(clip_sel->offer, TRUE);
     vwl_data_source_destroy(&clip_sel->source, FALSE);
     vwl_clipboard_free_mime_types(clip_sel);
@@ -2253,8 +2248,39 @@ wayland_cb_own_selection(
 	return FAIL;
 
     if (clip_sel->source.proxy != NULL)
-	// We already own the selection
-	return OK;
+    {
+	if (selection == WAYLAND_SELECTION_PRIMARY)
+	    // We already own the selection, ignore (only do this for primary
+	    // selection). We don't re set the selection because then we would
+	    // be setting the selection every time the user moves the visual
+	    // selection cursor, which is messy and inefficient.
+	    //
+	    // Vim doesn't have a mechanism to only set the selection
+	    // when the user stops selecting (such as the user releasing the
+	    // mouse button in graphical Wayland applications). So this
+	    // behaviour in Vim differs from other Wayland applications.
+	    return OK;
+	else if (selection == WAYLAND_SELECTION_REGULAR)
+	{
+	    // Technically we don't need to do this as we already own the
+	    // selection, however if a user yanks text a second time, the
+	    // text yanked won't appear in their clipboard manager if they are
+	    // using one.
+	    //
+	    // This can be unexpected behaviour for the user so its probably
+	    // better to do it this way. Additionally other Wayland applications
+	    // seem to set the selection every time.
+	    //
+	    // There should be no noticable performance change since its not
+	    // like this is running in the background constantly in Vim, only
+	    // runs once when the user yanks text to the system clipboard.
+	    vwl_data_source_destroy(&clip_sel->source, FALSE);
+	    vwl_display_flush(&vwl_display);
+	}
+	else
+	    // Shouldn't happen
+	    return FAIL;
+    }
 
     if (!wayland_client_is_connected(FALSE) ||
 	    !vwl_clipboard_selection_is_ready(clip_sel))
